@@ -4,7 +4,7 @@ from pathlib import Path
 
 import fire
 
-import vid
+import sonocrop.vid as vid
 
 
 
